@@ -189,7 +189,7 @@ class CLASSIX:
     """
         
 
-    def __init__(self, radius=0.5, sorting="pca", group_merging="density", minPts=0, norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=0): 
+    def __init__(self, radius=0.5, sorting="pca", group_merging="distance", minPts=0, norm=True, scale=1.5, post_alloc=True, n_jobs=-1, verbose=0): 
         # deprecated parameter (15/07/2021): noise_percent=0, distance_scale=1, eta=1, cython=True
         # eta (deprecated): float, default=1.0
         #     the value for the density-based groups merging, the groups will 
@@ -243,6 +243,7 @@ class CLASSIX:
             print(self)
         self.splist_indices = [None]
             
+            
     def fit(self, data):
         """ 
         Cluster the data.
